
[github](https://github.com/eaybek/sna/)  
[PyPi](https://pypi.org/project/sna/)  

sna means:

Search N Act

you can do 
search and replace
search and create
search and open
search and anything...

